@@ -1,14 +1,14 @@
-#' A simulated data consisting of 200 interval-censored observations with 2 covariates.
+#' Simulated data consisting of 200 interval-censored observations with 2 covariates.
 #'
 #' Data containing the last time point prior to the event, the first time point after the event, cause of failure, and covariates.
 #'
 #' @docType data
 #'
-#' @usage simdat
+#' @usage simdata
 #'
 #' @format A data frame with 200 rows and 5 variables.
 #'
 #' @keywords datasets
 #'
-#' @examples simdat
-"simdat"
+#' @examples simdata
+"simdata"
